@@ -1,4 +1,7 @@
+# rubocop:disable all
 class CreateLabelLinks < ActiveRecord::Migration
+  DOWNTIME = false
+
   def change
     create_table :label_links do |t|
       t.integer :label_id
